import { Language, LanguageDefinition, registerLanguage } from "./languageManager.js";
/**
 * @property {string} language - The language that the string should be highlighted as, Default is javascript.
 * @property {string} tailwind - Wether or not to use Tailwind CSS, Default is false.
 * @property {HighlighterColors} colors - The colors that should be used for highlighting.
 */
export interface SyntaxHighlighterOptions {
    language?: string;
    tailwind?: boolean;
    colors?: HighlighterColors;
}
/**
 * The colors for the syntax highlighter.
 * Colors can be in any format css supports when not using tailwind.
 * When using tailwind it can be any tailwind color found at https://tailwindcss.com/docs/text-color without the "text-" part.
 * View what types are what on https://en.wikipedia.org/wiki/Lexical_analysis#Lexical_token_and_lexical_tokenization
 */
export interface HighlighterColors {
    identifier: string;
    keyword: string;
    separator: string;
    operator: string;
    literals: {
        boolean: string;
        number: string;
        string: string;
        null: string;
    };
    comment: string;
}
/**
 * Gets a language definition for a given language name.
 * @param language The language name to get the language definition for.
 * @returns The language definition.
 */
export declare function getLanguageDefinition(language: string): LanguageDefinition;
/**
 * Highlight code in html syntax
 * @param code The code to be highlighted
 * @param options Options for highlighting
 */
export default function (code: string, options: SyntaxHighlighterOptions): string;
export { registerLanguage, LanguageDefinition, Language };
/**
 * Importing default languages.
 * Any non default language can be imported in the file that uses it.
*/
import "./JavaScript.js";
